@@ -439,27 +439,7 @@ local function multimap_callback(task, rule)
 
     local ret = false
 
-    if r['cdb'] then
-      if type(r.cdb) == 'string' then
-        local rspamd_cdb = require "rspamd_cdb"
-        local cdb = rspamd_cdb.create(r.cdb, task:get_ev_base())
-
-        if not cdb then
-          rspamd_logger.infox(task, 'cannot open cdb file %s', r.cdb)
-
-          return false
-        else
-          r.cdb = cdb
-        end
-      end
-      local srch = value
-      if type(value) == 'userdata' then
-        if value.class == 'rspamd{ip}' then
-          srch = value:tostring()
-        end
-      end
-      ret = r.cdb:lookup(srch)
-    elseif r.redis_key then
+    if r.redis_key then
       -- Deal with hash name here: it can be either plain string or a selector
       if type(r.redis_key) == 'string' then
         ret = multimap_query_redis(r.redis_key, task, value, callback)
@@ -590,7 +570,12 @@ local function multimap_callback(task, rule)
 
 
     if opt then
-      task:insert_result(forced, symbol, score, opt)
+      if type(opt) == 'table' then
+        task:insert_result(forced, symbol, score, fun.totable(fun.map(tostring, opt)))
+      else
+        task:insert_result(forced, symbol, score, tostring(opt))
+      end
+
     else
       task:insert_result(forced, symbol, score)
     end
@@ -861,6 +846,12 @@ local function multimap_callback(task, rule)
         end
       end
     end,
+    user = function()
+      local user = task:get_user()
+      if user then
+        match_rule(rule, user)
+      end
+    end,
     filename = function()
       local parts = task:get_parts()
 
@@ -868,8 +859,24 @@ local function multimap_callback(task, rule)
         return p:is_attachment() or (not p:is_text()) and (not p:is_multipart())
       end
 
+      local function filter_archive(p)
+        local ext = p:get_detected_ext()
+        local det_type = 'unknown'
+
+        if ext then
+          local lua_magic_types = require "lua_magic/types"
+          local det_t = lua_magic_types[ext]
+
+          if det_t then
+            det_type = det_t.type
+          end
+        end
+
+        return p:is_archive() and det_type == 'archive' and not rule.skip_archives
+      end
+
       for _,p in fun.iter(fun.filter(filter_parts, parts)) do
-        if p:is_archive() and not rule['skip_archives'] then
+        if filter_archive(p) then
           local fnames = p:get_archive():get_files()
 
           for _,fn in ipairs(fnames) do
@@ -1016,6 +1023,7 @@ local function add_multimap_rule(key, newrule)
     symbol_options = true,
     filename = true,
     url = true,
+    user = true,
     content = true,
     hostname = true,
     asn = true,
@@ -1066,11 +1074,7 @@ local function add_multimap_rule(key, newrule)
       newrule.selector = selector
     end
   end
-  -- Check cdb flag
-  if type(newrule['map']) == 'string' and string.find(newrule['map'], '^cdb://.*$') then
-    newrule['cdb'] = newrule['map']
-    ret = true
-  elseif type(newrule['map']) == 'string' and
+  if type(newrule['map']) == 'string' and
       string.find(newrule['map'], '^redis://.*$') then
     if not redis_params then
       rspamd_logger.infox(rspamd_config, 'no redis servers are specified, ' ..
